@@ -4,21 +4,19 @@ package Module::Install::InlineModule;
 our $VERSION = '0.01';
 
 use base 'Module::Install::Base';
-use Inline::Module;
-
-# use XXX;
+use Inline::Module();
 
 sub inline {
     my ($self, %args) = @_;
 
+    my $meta = \%args;
     my $makemaker = {};
     my $postamble = Inline::Module::postamble(
         $makemaker,
-        inline => \%args,
+        inline => $meta,
     );
     $self->postamble($postamble);
-    my $IM = $Inline::Module::Self;
-    for my $module ($IM->included_modules) {
+    for my $module (Inline::Module->included_modules($meta)) {
         $self->include($module);
     }
 }
